@@ -2,30 +2,31 @@ package App::LDAP::Command::Del::Ou;
 
 use Modern::Perl;
 
+use Namespace::Dispatch;
+
 use Moose;
 
-with qw( App::LDAP::Role::Command
-         App::LDAP::Role::Bindable );
+with 'MooseX::Getopt';
 
 has base => (
     is  => "rw",
     isa => "Str",
 );
 
+use App::LDAP::Utils;
 use App::LDAP::LDIF::OrgUnit;
 
 sub run {
     my ($self, ) = @_;
 
-    my $ouname = $self->extra_argv->[2] or die "no organization name specified";
+    my $ou = $ARGV[2] or die "no organization name specified";
 
-    my $ou = App::LDAP::LDIF::OrgUnit->search(
-        base   => config()->{base},
-        scope  => config()->{scope},
-        filter => "ou=$ouname",
+    App::LDAP::LDIF::OrgUnit->delete(
+        base   => config->{base},
+        scope  => config->{scope},
+        filter => "ou=$ou",
     );
 
-    $ou->delete;
 }
 
 1;
