@@ -2,11 +2,14 @@ package App::LDAP::Command::Migrate::User;
 
 use Modern::Perl;
 
+use Namespace::Dispatch;
+
 use Moose;
 
-with 'App::LDAP::Role::Command';
+with 'MooseX::Getopt';
 
 sub run {
+
 }
 
 __PACKAGE__->meta->make_immutable;
