@@ -1,33 +1,39 @@
-use 5.010;
-use strict;
-use warnings;
-
 package App::LDAP::Config;
 
+use Modern::Perl;
+use Moose;
+use MooseX::Singleton;
 
-use constant locations => qw(
+our @locations = qw(
   $ENV{HOME}/.ldaprc
   /etc/ldap.conf
   /etc/ldap/ldap.conf
   /usr/local/etc/ldap.conf
 );
 
-sub new {
-  my $class = shift;
-  bless {} ,$class;
-}
-
+our @has_scope = qw(
+    nss_base_passwd
+    nss_base_shadow
+    nss_base_group
+    nss_base_hosts
+    sudoers_base
+);
 
 sub read {
   my ($class, ) = @_;
   my $self = $class->new;
-  for ($class->locations) {
+  for (@locations) {
     if (-f $_) {
       open my $config, "<", $_;
       while (<$config>) {
         unless ($_ =~ /(^#|^\n)/) {
           my ($key, $value) = split /\s+/, $_;
-          $self->{$key} = $value;
+          my @value = split /\?/, $value;
+          if ($key ~~ @has_scope) {
+              $self->{$key} = [@value];
+          } else {
+              $self->{$key} = $value;
+          }
         }
       }
       last;
@@ -36,5 +42,4 @@ sub read {
   $self;
 }
 
-
 1;
